@@ -25,7 +25,7 @@ __version__ = "$Id: 0.py 2265 2010-02-21 19:16:26Z v13 $"
 import os
 import pickle
 
-version = "0.7"
+version = "0.7.1"
 
 try:
     from glib import get_user_config_dir
@@ -63,8 +63,8 @@ class Config:
 #	self.iconspace = 42	# For 4 icons (height)
 	self.iconspace = 36	# For 8 icons (width)
 	self.apps=None
-	self.indiv=False
-	self.longpress=True
+	self.indiv=True
+	self.longpress=False
 	self.animate=True
 
 	self.maxsz=(8,4)
