@@ -27,9 +27,22 @@ from drlaunch import widget
 class DrlaunchPlugin(widget.DrlaunchPlugin):
     pass
 
+def redirect_err():
+    import sys
+    import time
+
+    print "Opening /tmp/drlaunch.log"
+    f=open('/tmp/drlaunch.log', 'at', buffering=1)
+    sys.stdout=f
+    sys.stderr=f
+    print "Log open:", time.ctime()
+
 hd_plugin_type = DrlaunchPlugin
 
 if __name__=="__main__":
+    import gobject
+    import gtk
+
     gobject.type_register(hd_plugin_type)
     obj=gobject.new(hd_plugin_type, plugin_id="plugin_id")
     obj.show_all()
